pub struct PrecomputedKey(/* private fields */);Expand description
A precomputed shared key for public-key cryptography
This key is the result of the Diffie-Hellman key exchange between a public key and a secret key. It can be reused for multiple encryption/decryption operations with the same pair of keys, improving performance.
Properties
- Size: 32 bytes (256 bits)
- Derived from a public key and a secret key
- Must be kept confidential
- Can be used for multiple encryption/decryption operations
Implementations