pub struct SecretKey(/* private fields */);Expand description
A secret key for asymmetric encryption using X25519
This key is used for decrypting messages and must be kept private. It is randomly generated and used to derive the corresponding public key.
Properties
- Size: 32 bytes (256 bits)
- Based on the X25519 elliptic curve
- Must be kept confidential
- Used to decrypt messages that were encrypted with the corresponding public key
Implementations