Key

Struct Key 

pub struct Key(/* private fields */);
A key for deterministic IP address encryption

This key is used for the deterministic variant where the same input always produces the same output.

Implementations

Source

impl Key

pub fn generate() -> Self

Generates a new random key

pub fn from_slice(slice: &[u8]) -> Self

Creates a key from a byte slice

Panics

Panics if the slice is not exactly KEYBYTES bytes long

pub fn as_bytes(&self) -> &[u8]

Returns the key as a byte slice