pub struct Key(/* private fields */);Expand description
A key for deterministic IP address encryption
This key is used for the deterministic variant where the same input always produces the same output.
Implementations