pub fn version_string() -> &'static strExpand description
Returns the version string of the libsodium library
This function returns the version string of the libsodium library, which typically includes the major and minor version numbers.
Example
use libsodium_rs as sodium;
let version = sodium::version::version_string();
println!("libsodium version: {}", version);Returns
&'static str- The version string of the libsodium library